@@ -20,11 +20,13 @@ TIMEOUT = 36
 # 可处理的状态码
 STATUS_CODES = [200, 521]
 
-# 常见的网页空格符号
-WHITESPACE = ('\xa0', '\u3000', '\x0c', '&nbsp;', ' ')
+# 常见的空格符号、不可见字符
+WHITESPACE = ('\xa0', '\x0b', '\x0c', '&nbsp;',
+              '\u200b', '\u3000', ' ')
 
 # 一般无有效数据的标签
-USELESS_TAGS = ('script', 'style', 'input', 'iframe', 'head')
+USELESS_TAGS = ('script', 'style', 'input', 'iframe',
+                'head', 'textarea')
 
 # 格式化时间
 DATETIME_12 = r'%Y-%m-%d %I:%M:%S %p'  # 2020-07-02 08:17:54 AM
